@@ -44,13 +44,14 @@ sub preprocess_req {
 
 sub _build_models {
 	my ($self, $pkg, $path, $lib, $config) =@_; 
-	return $self->_load_modules(
+	my $models = $self->_load_modules(
 		path => $path,
 		pkg => $pkg,
 		type => 'Model',
 		lib => $lib,
 		config => $config
 	);
+	return $models;
 }
 
 sub _build_views {
@@ -200,7 +201,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =cut
 
